@@ -9,7 +9,9 @@
 #ifdef PARALLEL
 #include <mpi.h>
 #endif
+#ifndef GPAW_WITHOUT_LIBXC
 #include <xc.h>
+#endif
 
 #ifdef GPAW_HPM
 PyObject* ibm_hpm_start(PyObject *self, PyObject *args);
@@ -44,16 +46,16 @@ PyObject* NewTransformerObject(PyObject *self, PyObject *args);
 PyObject* pc_potential(PyObject *self, PyObject *args);
 PyObject* add_to_density(PyObject *self, PyObject *args);
 PyObject* utilities_gaussian_wave(PyObject *self, PyObject *args);
-PyObject* errorfunction(PyObject *self, PyObject *args);
-PyObject* cerf(PyObject *self, PyObject *args);
 PyObject* pack(PyObject *self, PyObject *args);
 PyObject* unpack(PyObject *self, PyObject *args);
 PyObject* unpack_complex(PyObject *self, PyObject *args);
 PyObject* hartree(PyObject *self, PyObject *args);
 PyObject* localize(PyObject *self, PyObject *args);
 PyObject* NewXCFunctionalObject(PyObject *self, PyObject *args);
+#ifndef GPAW_WITHOUT_LIBXC
 PyObject* NewlxcXCFunctionalObject(PyObject *self, PyObject *args);
 PyObject* lxcXCFuncNum(PyObject *self, PyObject *args);
+#endif
 PyObject* exterior_electron_density_region(PyObject *self, PyObject *args);
 PyObject* plane_wave_grid(PyObject *self, PyObject *args);
 PyObject* tci_overlap(PyObject *self, PyObject *args);
@@ -175,16 +177,16 @@ static PyMethodDef functions[] = {
     {"pwlfc_expand", pwlfc_expand, METH_VARARGS, 0},
     {"pw_insert", pw_insert, METH_VARARGS, 0},
     {"pw_precond", pw_precond, METH_VARARGS, 0},
-    {"erf", errorfunction, METH_VARARGS, 0},
-    {"cerf", cerf, METH_VARARGS, 0},
     {"pack", pack, METH_VARARGS, 0},
     {"unpack", unpack, METH_VARARGS, 0},
     {"unpack_complex", unpack_complex,           METH_VARARGS, 0},
     {"hartree", hartree, METH_VARARGS, 0},
     {"localize", localize, METH_VARARGS, 0},
     {"XCFunctional", NewXCFunctionalObject, METH_VARARGS, 0},
+#ifndef GPAW_WITHOUT_LIBXC
     {"lxcXCFunctional", NewlxcXCFunctionalObject, METH_VARARGS, 0},
     {"lxcXCFuncNum", lxcXCFuncNum, METH_VARARGS, 0},
+#endif
     {"tci_overlap", tci_overlap, METH_VARARGS, 0},
     {"vdw", vdw, METH_VARARGS, 0},
     {"vdw2", vdw2, METH_VARARGS, 0},
@@ -286,7 +288,9 @@ extern PyTypeObject WOperatorType;
 extern PyTypeObject SplineType;
 extern PyTypeObject TransformerType;
 extern PyTypeObject XCFunctionalType;
+#ifndef GPAW_WITHOUT_LIBXC
 extern PyTypeObject lxcXCFunctionalType;
+#endif
 
 PyObject* globally_broadcast_bytes(PyObject *self, PyObject *args)
 {
@@ -355,8 +359,10 @@ static PyObject* moduleinit(void)
         return NULL;
     if (PyType_Ready(&XCFunctionalType) < 0)
         return NULL;
+#ifndef GPAW_WITHOUT_LIBXC
     if (PyType_Ready(&lxcXCFunctionalType) < 0)
         return NULL;
+#endif
 
     PyObject* m = PyModule_Create(&moduledef);
 
@@ -369,10 +375,12 @@ static PyObject* moduleinit(void)
     PyModule_AddObject(m, "Communicator", (PyObject *)&MPIType);
 #endif
 
-#if XC_MAJOR_VERSION >= 3
+#ifndef GPAW_WITHOUT_LIBXC
+# if XC_MAJOR_VERSION >= 3
     PyObject_SetAttrString(m,
                            "libxc_version",
                            PyUnicode_FromString(xc_version_string()));
+# endif
 #endif
 
     Py_INCREF(&LFCType);
@@ -381,7 +389,9 @@ static PyObject* moduleinit(void)
     Py_INCREF(&SplineType);
     Py_INCREF(&TransformerType);
     Py_INCREF(&XCFunctionalType);
+#ifndef GPAW_WITHOUT_LIBXC
     Py_INCREF(&lxcXCFunctionalType);
+#endif
 #ifndef GPAW_INTERPRETER
     // gpaw-python needs to import arrays at the right time, so this is
     // done in gpaw_main().  In serial, we just do it here:
