@@ -8,9 +8,11 @@ def create_tasks():
              task('run_tests_emt.py', deps='agts.py')]
     deps = ['run_tests_emt.py']
     for name in all_optimizers:
-        tasks.append(task('run_tests.py+{}@8:1d'.format(name),
+        if name == 'Berny':
+            continue
+        tasks.append(task(f'run_tests.py+{name}@8:1d',
                           deps='agts.py'))
-        deps.append('run_tests.py+{}'.format(name))
+        deps.append(f'run_tests.py+{name}')
     tasks.append(task('analyze.py', deps=deps))
     return tasks
 
