@@ -7,12 +7,13 @@ import os
 import sys
 from sysconfig import get_platform
 from os.path import join, isfile
+from typing import List, Dict
 
 plat = get_platform()
 platform_id = os.getenv('CPU_ARCH')
 if platform_id:
     plat += '-' + platform_id
-build_path = join(__path__[0], '..', 'build')  # noqa
+build_path = join(__path__[0], '..', 'build')  # type: ignore
 arch = '{}-{}.{}'.format(plat, *sys.version_info[0:2])
 
 # If we are running the code from the source directory, then we will
@@ -32,11 +33,12 @@ with broadcast_imports:
 
     import numpy as np
     from ase.cli.run import str2dict
+    import _gpaw
 
 assert not np.version.version.startswith('1.6.0')
 
-__version__ = '20.1.0'
-__ase_version_required__ = '3.19.0'
+__version__ = '20.10.0'
+__ase_version_required__ = '3.20.1'
 
 __all__ = ['GPAW',
            'Mixer', 'MixerSum', 'MixerDif', 'MixerSum2',
@@ -70,6 +72,12 @@ def parse_extra_parameters(arg):
 
 is_gpaw_python = '_gpaw' in sys.builtin_module_names
 
+libraries: Dict[str, str] = {}
+if hasattr(_gpaw, 'lxcXCFunctional'):
+    libraries['libxc'] = getattr(_gpaw, 'libxc_version', '2.x.y')
+else:
+    libraries['libxc'] = ''
+
 
 def parse_arguments(argv):
     p = ArgumentParser(usage='%(prog)s [OPTION ...] [-c | -m] SCRIPT'
@@ -187,18 +195,10 @@ extra_parameters.update(parse_gpaw_args())
 
 # Check for special command line arguments:
 memory_estimate_depth = gpaw_args.memory_estimate_depth
-parsize_domain = gpaw_args.parsize_domain
-parsize_bands = gpaw_args.parsize_bands
-augment_grids = gpaw_args.augment_grids
-# We deprecate the sl_xxx parameters being set from command line.
-# People can satisfy their lusts by setting gpaw.sl_default = something
-# if they are perverted enough to use global variables.
-sl_default = None
-sl_diagonalize = None
-sl_inverse_cholesky = None
-sl_lcao = None
-sl_lrtddft = None
-buffer_size = gpaw_args.buffer_size
+parsize_domain: int = gpaw_args.parsize_domain
+parsize_bands: int = gpaw_args.parsize_bands
+augment_grids: int = gpaw_args.augment_grids
+buffer_size: int = gpaw_args.buffer_size
 profile = gpaw_args.profile
 
 
@@ -219,7 +219,7 @@ def main():
 
 
 dry_run = extra_parameters.pop('dry_run', 0)
-debug = extra_parameters.pop('debug', sys.flags.debug)
+debug: bool = extra_parameters.pop('debug', sys.flags.debug)
 benchmark_imports = extra_parameters.pop('benchmark_imports', False)
 
 # Check for typos:
@@ -252,7 +252,7 @@ def get_gpaw_python_path():
     raise RuntimeError('Could not find gpaw-python!')
 
 
-setup_paths = []
+setup_paths: List[str] = []
 
 
 with broadcast_imports:
@@ -268,6 +268,15 @@ with broadcast_imports:
 
 RMM_DIIS = RMMDIIS
 
+if os.environ.get('GPAW_COVERAGE'):
+    import atexit
+    import coverage
+    from gpaw.mpi import rank
+    name = os.environ['GPAW_COVERAGE']
+    cov = coverage.Coverage(f'coverage-{name}-{rank}', True)
+    cov.start()
+    atexit.register(lambda: [cov.stop(), cov.save()])
+
 
 def restart(filename, Class=GPAW, **kwargs):
     calc = Class(filename, **kwargs)
