@@ -1,15 +1,12 @@
 from math import sqrt
 
 import numpy as np
-
 from ase.atoms import Atoms
 from ase.units import Bohr, Hartree
-from ase.io.cube import write_cube
-from ase.io.plt import write_plt, read_plt
+from ase.io.cube import read_cube_data, write_cube
 from ase.dft.stm import STM
 
 import gpaw.mpi as mpi
-from gpaw.mpi import MASTER
 from gpaw.grid_descriptor import GridDescriptor
 
 
@@ -35,7 +32,7 @@ class SimpleStm(STM):
         else:
             if isinstance(atoms, Atoms):
                 self.atoms = atoms
-                self.calc = atoms.get_calculator()
+                self.calc = atoms.calc
             else:
                 self.calc = atoms
                 self.atoms = self.calc.get_atoms()
@@ -58,19 +55,18 @@ class SimpleStm(STM):
         if hasattr(bias, '__len__') and len(bias) == 3:
             n, k, s = bias
             # only a single wf requested
-            u = self.calc.wfs.kd.where_is(k, s)
-            if u is not None:
+            kd = self.calc.wfs.kd
+            rank, q = kd.who_has(k)
+            if kd.comm.rank == rank:
+                u = q * kd.nspins + s
                 self.add_wf_to_ldos(n, u, weight=1)
 
         else:
             # energy bias
             try:
-                if self.calc.occupations.fixmagmom:
-                    efermi_s = self.calc.get_fermi_levels()
-                else:
-                    efermi_s = np.array([self.calc.get_fermi_level()] * 2)
-            except:  # XXXXX except what?
-                efermi_s = np.array([self.calc.get_homo_lumo().mean()] * 2)
+                efermi_s = self.calc.get_fermi_levels()
+            except ValueError:
+                efermi_s = np.array([self.calc.get_fermi_level()] * 2)
 
             if isinstance(bias, (int, float)):
                 # bias given
@@ -130,18 +126,17 @@ class SimpleStm(STM):
         ldos = self.gd.collect(self.ldos)
 # print "write: integrated =", self.gd.integrate(self.ldos)
 
-        if mpi.rank != MASTER:
+        if mpi.rank != 0:
             return
 
         if filetype is None:
             # estimate file type from name ending
             filetype = file.split('.')[-1]
-        filetype.lower()
+        filetype = filetype.lower()
 
         if filetype == 'cube':
-            write_cube(file, self.calc.get_atoms(), ldos / Bohr ** 3)
-        elif filetype == 'plt':
-            write_plt(file, self.calc.get_atoms(), ldos / Bohr ** 3)
+            with open(file, 'w') as fd:
+                write_cube(fd, self.calc.get_atoms(), ldos / Bohr ** 3)
         else:
             raise NotImplementedError('unknown file type "' + filetype + '"')
 
@@ -151,10 +146,10 @@ class SimpleStm(STM):
         if filetype is None:
             # estimate file type from name ending
             filetype = file.split('.')[-1]
-        filetype.lower()
 
-        if filetype == 'plt':
-            data, self.cell = read_plt(file)
+        if filetype == 'cube':
+            data, atoms = read_cube_data(file)
+            self.cell = atoms.cell.array
 
             pbc_c = [True, True, True]
             N_c = np.array(data.shape)
@@ -207,7 +202,7 @@ class SimpleStm(STM):
     def write(self, file=None):
         """Write STM data to a file in gnuplot readable tyle."""
 
-        if mpi.rank != MASTER:
+        if mpi.rank != 0:
             return
 
         xvals, yvals, heights = self.pylab_contour()
@@ -220,11 +215,8 @@ class SimpleStm(STM):
             fname = file
         f = open(fname, 'w')
 
-        try:
-            import datetime
-            print('#', datetime.datetime.now().ctime(), file=f)
-        except:  # XXX except what?
-            pass
+        import datetime
+        print('#', datetime.datetime.now().ctime(), file=f)
         print('# Simulated STM picture', file=f)
         if hasattr(self, 'file'):
             print('# density read from', self.file, file=f)
