@@ -5,8 +5,7 @@
 # Computer generated code:
 # format:
 #    'element': (atomic number, [(n, l, occ, energy), ...])
-from __future__ import print_function
-
+from typing import Dict, Any
 import copy
 
 configurations = {
@@ -1045,7 +1044,7 @@ configurations['No'][1][15] = (5, 3, 14, -0.36654300000000001)
 configurations['No'][1][16] = (6, 2, 0, -0.14319000000000001)
 
 
-parameters = {
+parameters: Dict[str, Dict[str, Any]] = {
  'H' : {'rcut': 0.9},
  'He': {'rcut': 1.5},
  'Li': {'core': '[He]',       'rcut': 2.0},
@@ -1309,19 +1308,19 @@ if __name__ == '__main__':
     # http://www.physics.nist.gov/PhysRefData/DFTdata/
     path = '/scratch/jensj/dftdata/'
     Ztable = {}
-    configurations = [['X', '']]
+    confs = [['X', '']]
     Z = 1
     for line in open(path + 'configurations'):
         if len(line) > 1 and line[1].isdigit():
-            line = line[:44].split()
-            symbol = line[1]
+            words = line[:44].split()
+            symbol = words[1]
             Ztable[symbol] = Z
-            configurations.append(line[2:])
+            confs.append(words[2:])
             Z += 1
 
     def get_occupations(symbol):
         Z = Ztable[symbol]
-        configuration = configurations[Z]
+        configuration = confs[Z]
         if configuration[0][0] == '[':
             occupations = get_occupations(configuration[0][1:-1])
             configuration = configuration[1:]
@@ -1346,8 +1345,8 @@ if __name__ == '__main__':
         for state, occ in occupations:
             n = int(state[0])
             l = spdf[state[1]]
-            eps = epsilons[state]
-            nloe.append((n, l, occ, eps))
+            e = epsilons[state]
+            nloe.append((n, l, occ, e))
         dftdata[symbol] = (Z, nloe)
     print('# Computer generated code:')
     print()
