@@ -65,7 +65,7 @@ UL = 'L'
 
 # Generate the coefficients for the Fourier-Bessel transform
 C = []
-a = 0.0
+a = 0.0 + 0.0j
 LMAX = 7
 for n in range(LMAX):
     c = np.zeros(n + 1, complex)
@@ -755,7 +755,8 @@ class NewTwoCenterIntegrals:
                                                                 True))
 
         scale = 0.01  # XXX minimal distance scale
-        cutoff_close_a = [covalent_radii[s.Z] / Bohr * scale for s in setups]
+        cutoff_close_a = [covalent_radii[int(s.Z)] / Bohr * scale
+                          for s in setups]
         self.atoms_close = NeighborPairs(cutoff_close_a, cell_cv, pbc_c, False)
 
         rcmax = max(cutoff_I + [0.001])
