@@ -372,11 +372,11 @@ class LrTDDFT2:
                     raise RuntimeError('Converge wave functions first.')
 
                 spos_ac = self.calc.initialize_positions()
-                self.calc.occupations.calculate(self.calc.wfs)
+                self.calc.wfs.calculate_occupation_numbers()
                 self.calc.wfs.initialize(self.calc.density,
                                          self.calc.hamiltonian, spos_ac)
                 self.xc.initialize(self.calc.density, self.calc.hamiltonian,
-                                   self.calc.wfs, self.calc.occupations)
+                                   self.calc.wfs)
                 if mode == 'lcao':
                     self.calc.wfs.initialize_wave_functions_from_lcao()
                 self.calc_ready = True
