@@ -8,7 +8,7 @@ slab.set_cell([[7.309254, 0., 0.], [4.872836, 7.509545, 0.], [0., 0., 20.]],
 slab.set_pbc((1,1,1))
 
 calc = GPAW(h=0.18, kpts=(4, 4, 1))
-slab.set_calculator(calc)
+slab.calc = calc
 
 dyn = BFGSLineSearch(slab,trajectory='relax.traj')
 dyn.run(fmax=0.02)
