@@ -1,4 +1,3 @@
-from __future__ import print_function
 from ase import Atom, Atoms
 from ase.optimize.bfgslinesearch import BFGSLineSearch
 from ase.io import read
@@ -17,13 +16,13 @@ kwargs_lcao = dict(mode='lcao',
               convergence={'density':0.1, 'energy':0.1})
 
 calc = GPAW(h=0.18,txt=None,**kwargs_lcao)
-cluster.set_calculator(calc)
+cluster.calc = calc
 
 dyn1 = BFGSLineSearch(cluster, trajectory='Au_cluster_lcao.traj')
 dyn1.run(fmax=0.02)
 e_cluster_lcao = cluster.get_potential_energy()
 
-#cluster.set_calculator(GPAW(h=0.18,tex=None))
+#cluster.calc = GPAW(h=0.18,tex=None)
 dyn2 = BFGSLineSearch(cluster, trajectory='Au_cluster_paw.traj')
 dyn2.run(fmax=0.02)
 e_cluster_paw = cluster.get_potential_energy()
@@ -32,13 +31,13 @@ e_cluster_paw = cluster.get_potential_energy()
 CO = Atoms([Atom('C',(1.0,1.0,1.0)),
             Atom('O',(1.0,1.0,2.3))],
             cell=(12,12.5,14.5))
-CO.set_calculator(calc)
+CO.calc = calc
 CO.center()
 dyn3 = BFGSLineSearch(CO)
 dyn3.run(fmax=0.02)
 e_CO_lcao = CO.get_potential_energy()
 
-CO.set_calculator(GPAW(h=0.18,tex=None))
+CO.calc = GPAW(h=0.18,tex=None)
 dyn4 = BFGSLineSearch(CO)
 dyn4.run(fmax=0.02)
 e_CO_paw = CO.get_potential_energy()
@@ -56,12 +55,12 @@ CO = Atoms([Atom('C', pos[0]),
 cluster.extend(CO)
 
 #Relax the CO adsorbed Au cluster with both Lcao and paw modes
-cluster.set_calculator(calc)
+cluster.calc = calc
 dyn5 = BFGSLineSearch(cluster, trajectory='CO_cluster_lcao.traj')
 dyn5.run(fmax=0.02)
 e_cocluster_lcao = cluster.get_potential_energy()
 
-cluster.set_calculator(GPAW(h=0.18,tex=None))
+cluster.calc = GPAW(h=0.18,tex=None)
 dyn6 = BFGSLineSearch(cluster, trajectory='CO_cluster_paw.traj')
 dyn6.run(fmax=0.02)
 e_cocluster_paw = cluster.get_potential_energy()
