@@ -1,5 +1,4 @@
 """Utilities to measure and estimate memory"""
-from __future__ import print_function
 
 # The functions  _VmB, memory, resident, and stacksize are based on
 # Python Cookbook, recipe number 286222
@@ -23,7 +22,7 @@ def _VmB(VmKey):
         t.close()
         # get VmKey line e.g. 'VmRSS:  9999  kB\n ...'
         i = v.index(VmKey)
-    except (IOError, KeyError, ValueError):
+    except (IOError, ValueError):
         return 0.0  # non-Linux?
 
     v = v[i:].split(None, 3)  # whitespace
@@ -68,7 +67,7 @@ def maxrss():
             if mm < (1024)**2:  # 1 MiB
                 mm = mm * 1024  # then mm was probably in KiB so convert to MiB
             return mm
-    except ImportError:
+    except (TypeError, ImportError):
         pass
 
     return 0.0  # no more ideas
@@ -110,7 +109,7 @@ class MemNode:
 
         The depth parameter determines indentation.  maxdepth of -1 means
         infinity."""
-        print(''.join([depth * self.indent, self.name, '  ',
+        print(''.join([depth * self.indent, self.name, ': ',
                        self.memformat(self.totalsize)]), file=txt)
         if depth == maxdepth:
             return
@@ -132,6 +131,7 @@ class MemNode:
         """Create subcomponent with given name and intrinsic size.  Use this
         to build component tree."""
         mem = MemNode(name, basesize)
+        mem.indent = self.indent
         self.nodes.append(mem)
         return mem
 
@@ -144,7 +144,7 @@ def monkey_patch_timer():
     
     Call this function before the actual work is done.  Then do::
         
-        $ sort -n mem.????
+        $ less mem.????
         
     to see where the memory is allocated."""
 
@@ -164,21 +164,17 @@ def monkey_patch_timer():
         self.t0 = time()
         
     def start(self, name):
-        st(self, name)
-        self.mem.append((time(), maxrss()))
+        st(self, name) 
+        print('start %14.6f %12d %s' % (time() - self.t0, maxrss(), name),
+              file=self.fd)
+        self.fd.flush()
         
     def stop(self, name=None):
         names = sp(self, name)
-        t1, m1 = self.mem.pop()
-        t2 = time()
-        m2 = maxrss()
-        self.mem = [(t, m + m2 - m1) for t, m in self.mem]
-        if m2 - m1 != 0:
-            print('%12d %14.6f %12d %14.6f %s' % (m2 - m1, t1 - self.t0, m2,
-                                                  t2 - t1,
-                                                  '.'.join(names)),
-                  file=self.fd)
-            self.fd.flush()
+        print('stop  %14.6f %12d %s' % (time() - self.t0, maxrss(),
+                                        '.'.join(names)),
+              file=self.fd)
+        self.fd.flush()
 
     Timer.__init__ = init
     Timer.start = start
